/*******************************************************************************

Title: 			05_anthro_construct_health_paper.do
Author(s): 		Caleb Jeremie Dohou & Luca Stanus Ghib
Description: 	This dofile loads the clean data and constructs variables and indices.
Input: 	"${clean}", see global defined in Project_MasterDofile.do
Output:	"${constructed}", see global defined in Project_MasterDofile.do

*******************************************************************************/

******** load raw dataset
use "${hp_anthro_clean}", clear

**** Generate variables for igrowup_ado
* construct date of birth as Stata date (currently we have separate day, month, and year of birth)
generate 	selected_date_birth = mdy(selected_month_birth, selected_day_birth, selected_year_birth) // function exists only in US format, no need to convert it though
format 		selected_date_birth %td

* construct age in days as difference between start_measures (data of measurement) & date of birth
generate age_days = abs(selected_date_birth - start_measures)

* construct age unit
generate ageunit = "days" // they are all in days

* construct variable for recumbent
generate 	measure = "L" if measured_upright == 0
replace 	measure = "H" if measured_upright == 1

* construct oedema variable
generate oedema = . // we don't collect this so needs to be missing value
gen head = .
gen muac = . 
gen tri = .
gen subskin = .
gen sw = . 

* reverse labels of gender variable for the ado to work as intended, create new variable
generate 	selected_child_sex_rev = 1 if selected_child_sex == 2
replace 	selected_child_sex_rev = 2 if selected_child_sex == 1

* Recode gender variable for regression
recode selected_child_sex (1 = 1 Female) (2 = 0 Male), gen(selected_child_sex_new) label(sex)

gen child_sex = selected_child_sex_new
label values child_sex sex
label var child_sex "Child's sex"

gen child_age_years = selected_age_years
label var child_age_years "Child's age (years)"

* generate datalab argument
generate datalab = "vea_anthro"

**** Add treatment status & cluster info to dataset so that it can be used for analysis
merge m:1 village using "${hp_village_list}", keepusing(treatment_status group cluster_strata) // 3 villages not matched from master list, consistent with villages having been dropped

* Drop the 3 villages that could not match
drop if _merge == 2

drop _merge


******** CALCULATE z scores using igrowup
cd "${hp_igrowup_ado}"

preserve
adopath + "99_igrowup_ados"

* Create variables needed by igrowup do files
	* gen str60 reflib="99_igrowup_ados"
	gen str60 reflib="macros_reftables"
	lab var reflib "Directory of reference tables" 
	* gen str60 datalib="98_igrowup_output"
	gen str60 datalib="anthro_z_scores" // since it's a string it gets truncated so I can't use the intermediate data global, need to output in the same location as the directory defined above, so I generated this folder myself (not part of the original zip package) to store the z-score tables generated with our own anthro data!
	lab var datalib "Directory for datafiles"
	lab var datalab "Working file"
	*gen sex = .
	*	replace sex=1 if selected_child_sex == 2
	*	replace sex=2 if selected_child_sex == 1

	*gen ageunit="days"
	*gen age = age_days
*	gen lenhei=.
*	gen str1 measure=" "
*	gen headc=.
*	gen armc=.
*	gen triskin=.
*	gen subskin=.
*	gen str1 oedema="n"
	*gen sw=1
	*gen muac=LL_q160_circumference
	
	* Fill in the macro parameters, and run

	igrowup_standard reflib datalib datalab selected_child_sex_rev age_days ageunit weight height measure head muac tri subskin oedema sw // This line of code was producing an error. I had to open the ado file, search for all "xxx", and replace the back slash "\" next to them into "/" for this line of code to work.

restore

****** Create binary indicators for stunting, wasting, underweight
	* Load dataset created by igrowup_standard command
	* use "98_igrowup_output\vea_anthro_z_st.dta", clear
	use "anthro_z_scores/vea_anthro_z_st.dta", clear
	
* Stunting
generate 	stunted = 0
replace 	stunted = 1 	if _zlen <= -2 // 1258 observations

* Wasting
generate 	wasted = 0
replace 	wasted = 1 		if _zwfl <= -2 // 68 observations

* Underweight
generate 	underweight = 0
replace 	underweight = 1 if _zwei <= -2 // 504 observations

*** Code for dropping observations with implausible z-scores (automatically calculated by the igrowup algorithm)
drop if _fwfl == 1 | _flen == 1 | _fwei == 1 // 44 observations dropped. Drop if either of these display an implausible z-score, we can decide to refine by separating the regression below so that we can separately say, do the regression only with _flen == 0 for the corresponding _zlen outcome (i.e. drop only values with implausible length-for-age z-score when looking at the length-for-age z-score as outcome, and disregard issues with the other outcomes), although I can see how with good quality data (as we have) and a very low number of observations, it won't really make a difference, might as well do this (which is actually conservative, because it excludes e.g. observations with an implausible length-for-age when looking for instance at weight-for-age or weight-for-height). If we decide to do it for each variable instead, the easiest way to do it while keeping the same structure of global+repeated reg+populating matrix is to create a new outcome variable w/implausible observations set as missing (easy if statement based on dummy that includes the info on implausible z-scores for each outcome).

*** Winsorization
winsor2 _zlen _zwei _zwfl, suffix(_winsor) // default command: winsorised at 1st and 99th percentiles (not trimmed!)

label var _zlen "Length-for-age z-score"
label var _zwei "Weight-for-age z-score"
label var _zwfl "Weight-for-length z-score"

label var _zlen_winsor "Length-for-age z-score"
label var _zwei_winsor "Weight-for-age z-score"
label var _zwfl_winsor "Weight-for-length z-score"


*save "anthro_z_scores/vea_anthro_z_st_constructed_health_paper.dta", replace
save "${hp_anthro_z_constructed}", replace

* end of dofile *
