/*******************************************************************************

Title: 			05_construct.do
Author(s): 		Luca Stanus Ghib
Description: 	This dofile loads the clean data and constructs variables and indices.
Input: 	"${clean}", see global defined in Project_MasterDofile.do
Output:	"${constructed}", see global defined in Project_MasterDofile.do

*******************************************************************************/

******** load clean dataset
use "${hp_hh_clean}", clear

**** Add treatment status & cluster info to dataset so that it can be used for analysis
merge m:1 village using "${hp_village_list}", keepusing(treatment_status group cluster_strata) // 3 villages not matched from master list, consistent with villages having been dropped

drop if _merge == 2

** Drop household that refused to participate
drop if consent == 0 // 2 obs deleted

*** Drop HHs that were replaced for some reason
drop if consent == .

******** Household-level construction section
* improved water source
/*
JMP 2017 categorisation:
Improved
- tap water in the dwelling, yard, or plot
- public standposts
- borehols/tubewells
- protected wells and springs
- rainwater
- packaged water (bottled, sachet, etc)
- delivered water (tanker trucks, etc)

Unimproved
- unprotected wells and springs

*/

generate 	watersourceimproved = . 
replace 	watersourceimproved = 1 if main_drink_source == 1 | main_drink_source == 2 | main_drink_source == 3 | main_drink_source == 5 | main_drink_source == 6 | main_drink_source == 7 | main_drink_source == 9 | main_drink_source == 11
replace 	watersourceimproved = 0 if main_drink_source == 4 | main_drink_source == 8 | main_drink_source == 10 | main_drink_source == 0
label var 	watersourceimproved "Water source improved (JMP definition)"

* improved latrine (code from midline doesn't apply fully because we had a select multiple var back then so it required extra steps, at endline instead we only asked about the main one and asked the enumerator to classify it--we are however obviously using the same categorisation used at midline)
generate 	improvedsanitation = .
replace 	improvedsanitation = 0 if defec_facility_hh == 4 | defec_facility_hh == 5 | defec_facility_hh == 9 | defec_facility_hh == 10 | defec_facility_hh == 11 | defec_facility_hh == 12 | defec_facility_hh == -555 // everything else not used below + other specify
replace 	improvedsanitation = 1 if defec_facility_hh == 1 | defec_facility_hh == 2 | defec_facility_hh == 3 | defec_facility_hh == 6 | defec_facility_hh == 7 | defec_facility_hh == 8  // flush to sewer, flush to septic, flush to pit latrine, vip latrine, pit latrine slab, composting latrine
label var 	improvedsanitation "Improved sanitation (JMP definition)"


***** Time to collect water
/* fetchround_hrs_trip_* fetchround_mins_trip_* contain respectively the hour and minute components of the total time spent collecting water (measured as total time of round trip), where "*" stands for each water trip. */

* convert hrs variable to minutes
forvalues i = 1/13 {
	generate water_trip_hrs_to_min_`i' = fetchround_hrs_trip_`i' * 60 // convert each hour component of the trip duration to minutes
}

* create trip-level variable containing total time in minutes
forvalues i = 1/13 {
	egen water_trip_in_mins_`i' = rowtotal(water_trip_hrs_to_min_`i' fetchround_mins_trip_`i') // sum hrs component converted to minutes + minutes component, use rowtotal() so that missing values get treated correctly
	label variable water_trip_in_mins_`i' "Total round trip duration in minutes"
}

* generate total duration of all round trips in the roster
egen watertriptotalminsalltrips = rowtotal(water_trip_in_mins_*)
label var watertriptotalminsalltrips "Total time in mins spent collecting water by the household in the previous day"

 *Winsorize outcomes with outliers at 99th percentile (right-winsorization only)
winsor2 watertriptotalminsalltrips, ///
 cuts(0 99) suffix(_win99) label

* generate hyperbolic sine of water trip legnth
gen watertriptotalminsalltrips_ihs = asinh(watertriptotalminsalltrips_win99)

********* Variables for balance table
/* -	Type of roof (improved roof= 1 if roof is finished roofing (i.e. Metal,
 Wood, Calamine/Cement fiber Ceramic tiles, Cement, or Roofing shingles) */
generate improvedroof = .
replace improvedroof = 1 if room_roof == 8 | room_roof == 9 | room_roof == 10 | room_roof == 11 | room_roof == 12 | room_roof == 13
replace improvedroof = 0 if room_roof == 1 | room_roof == 2 | room_roof == 3 | room_roof == 4 | room_roof == 5 | room_roof == 6 | room_roof == 7 | room_roof == -555
label var improvedroof "= 1 if roof is finished roofing (metal, wood, etc)"
 
/* -	Wall (improved walls = 1 if walls are "finished walls" */
generate improvedwall = .
replace improvedwall = 0 if room_wall == 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | -555
replace improvedwall = 1 if room_wall == 10 | room_wall == 11
label var improvedwall "= 1 if walls are finished walls"


/*-	Floor (improved floor= 1 if floor is "finished floor") */
*replace room_floor = "-555" if room_floor== "other"
generate improvedfloor = .
replace improvedfloor = 0 if room_floor == 1 | room_floor == 2 | room_floor == 3 | room_floor == 4 | room_floor == -555
replace improvedfloor = 1 if room_floor == 5 | room_floor == 6 | room_floor == 7 | room_floor == 8 | room_floor == 9

/* Religion: create binary religion variables */
*replace religion= "-555" if religion=="other"
generate nonreligious = .
replace nonreligious = 0 if religion == 1 | 2 | 3 | 4 | 5 | 6 | 7
replace nonreligious = 1 if religion == 0

generate catholic = .
replace catholic = 0 if religion == 0 | 2 | 3 | 4 | 5 | 6 | 7
replace catholic = 1 if religion == 1

generate protestant = .
replace protestant = 0 if religion == 0 | 1 | 3 | 4 | 5 | 6 | 7
replace protestant = 1 if religion == 2

generate muslim = .
replace muslim = 0 if religion == 0 | 1 | 2 | 4 | 5 | 6 | 7
replace muslim = 1 if religion == 3

generate jehovaswitness = .
replace jehovaswitness = 0 if religion == 0 | 1 | 2 | 3 | 5 | 6 | 7
replace jehovaswitness = 1 if religion == 4

generate kimbanguiste = .
replace kimbanguiste = 0 if religion == 0 | 1 | 2 | 3 | 4 | 6 | 7
replace kimbanguiste = 1 if religion == 5

generate anglican = .
replace anglican = 0 if religion == 0 | 1 | 2 | 3 | 4 | 5 | 7
replace anglican = 1 if religion == 6

generate methodist = .
replace methodist = 0 if religion == 0 | 1 | 2 | 3 | 4 | 5 | 6
replace methodist = 1 if religion == 7

generate other_religion = .
replace other_religion = 0 if religion == 0 | 1 | 2 | 3 | 4 | 5 | 6 | 7
replace other_religion = 1 if religion == -555

* Mother Tongue: Create binary language variables
*replace mother_tongue= "-555" if mother_tongue=="other"

generate lang_lingala = .
replace lang_lingala = 0 if mother_tongue == 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10
replace lang_lingala = 1 if mother_tongue == 1

generate lang_kikongo = .
replace lang_kikongo = 0 if mother_tongue == 1 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10
replace lang_kikongo = 1 if mother_tongue == 2

generate lang_tshikuba = . 
replace lang_tshikuba = 0 if mother_tongue == 1 | 2 | 4 | 5 | 6 | 7 | 8 | 9 | 10
replace lang_tshikuba = 1 if mother_tongue == 3

generate lang_bindi = .
replace lang_bindi = 0 if mother_tongue == 1 | 2 | 3 | 5 | 6 | 7 | 8 | 9 | 10
replace lang_bindi = 1 if mother_tongue == 4

generate lang_tshiluba = .
replace lang_tshiluba = 0 if mother_tongue == 1 | 2 | 3 | 4 | 6 | 7 | 8 | 9 | 10
replace lang_tshiluba = 1 if mother_tongue == 5

generate lang_french = .
replace lang_french = 0 if mother_tongue == 1 | 2 | 3 | 4 | 5 | 7 | 8 | 9 | 10
replace lang_french = 1 if mother_tongue == 6

generate lang_swahili = .
replace lang_swahili = 0 if mother_tongue == 1 | 2 | 3 | 4 | 5 | 6 | 8 | 9 | 10
replace lang_swahili = 1 if mother_tongue == 7

generate lang_mashi = .
replace lang_mashi = 0 if mother_tongue == 1 | 2 | 3 | 4 | 5 | 6 | 7 | 9 | 10
replace lang_mashi = 1 if mother_tongue == 8

generate lang_kihavu = .
replace lang_kihavu = 0 if mother_tongue == 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 10
replace lang_kihavu = 1 if mother_tongue == 9

generate lang_kihutu = .
replace lang_kihutu = 0 if mother_tongue == 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9
replace lang_kihutu = 1 if mother_tongue == 10

generate marriedorcohab = .
replace marriedorcohab = 0 if marital_status == 2 | 3 | 4
replace marriedorcohab = 1 if marital_status == 1

generate divorcedorseparated = .
replace divorcedorseparated = 0 if marital_status == 1 | 3 | 4
replace divorcedorseparated = 1 if marital_status == 2

generate widowed = .
replace widowed = 0 if marital_status == 1 | 2 | 4
replace widowed = 1 if marital_status == 3

generate single = .
replace single = 0 if marital_status == 1 | 2 | 3
replace single = 1 if marital_status == 4

*Respondent education: primary school completed
recode resp_educ (0/3 = 0) (3/9 = 1), gen(resp_prim_sch_complete)
*Respondent education: secondary school completed
recode resp_educ (0/4 = 0) (5/9 = 1), gen(resp_sec_sch_complete)

***** Generate weekly indicator for weekly FEs in school attendance regression
generate double enddate_child_roster = clock(end_endl_child_roster, "YMDhms") // using end timestamp of child roster
format enddate_child_roster %tc

*gen week = wofd(dofc(submissiondate))
gen week = wofd(dofc(enddate_child_roster))

***** Create dummy for interviews that happened within winter holiday (end of year break) or a week right after
* We consider a week right after as well since the question on children's school attendance refers to the week before
gen winter_holiday = (dofc(enddate_child_roster) <= date("15jan2023", "DMY") & dofc(enddate_child_roster) >= date("1jan2023", "DMY")) // The winter holiday case did not happen in Kongo Central but only in Kasai Central, Kasai et Sud Kivu
tab winter_holiday, mi

label define winter_holiday 1 "winter holiday" 0 "No winter holiday"
label value winter_holiday winter_holiday
label var winter_holiday "Last week was in winter holiday"

******* Self-reported hygiene behaviour indicators
** Caregiver knows how and when to wash hands -> create indicator = 1 if respondent mentioned unprompted that they wash hands with soap/ash in critical juncture X (= 0 if they say no or they say it prompted), add them up to create score
local hw_junctures hw_toilet-hw_field

foreach var of varlist `hw_junctures' {
	gen 	`var'_dummy = 1 if `var' == 1 // we only consider if unprompted
	replace `var'_dummy = 0 if `var' == 2 | `var' == 0
}

egen hw_score = rowtotal(hw_toilet_dummy-hw_field_dummy)
gen hw_know_share = hw_score/10
gen hw_know = (hw_score > 0) if hw_score !=. 
gen hw_know_3plus = (hw_score >=3) if hw_score != .
tab1 used_soap_ash hw_know hw_know_3plus, mi

** Open defecation -> =1 if no defecation facility used
gen 	open_defecation = .
replace open_defecation = 1 if defec_facility_hh == 12
replace open_defecation = 0 if defec_facility_hh != 12 & !missing(defec_facility_hh)


** Has a clean pot for water that is covered -> indicator equal to 1 if both of these things are true at the same time, i.e. pot is clean, pot is covered
gen 	clean_covered_pot = 0
replace clean_covered_pot = 1 if water_pot_clean == 1 & pot_covered == 1
replace clean_covered_pot = . if water_pot_clean == . & pot_covered == .

**** Water use expenditure ****



** Convert water use expenditure to a monthly measure.
* 1- Save the different conversion measures into scalars
* 2- Generate flate rate fee as a monthly measure [This does not include flate rate fee for which we do not have the period/frequency of payment (58 HHs). For these cases, other specify has been selected for the variable flatrate_period and no comment was provided on the frequency]
* 3- Add monthly measure of per use fee data points [(1) For variable water_fee_mthly, we use the per use fee paid by the HH in the past week and convert it into a monthly measure; (2) For variable water_fee_mthly2, we use the respondent's standard per use fee times the number of water collection trip taken by the HHs in the past week and convert it into a monthly measure]

bysort treatment_status: count if flatrate_period == -555 // We may update the other specify in the cleaning do-file

tab flatrate_period, mi


**** conversion to a week unit *****
*scalar oneweek = 1
scalar twoweeks = 2
scalar onemonth = 4.34524
scalar twomonths = 8.69049
scalar threemonths = 13.0357
scalar sixmonths = 26.0715
scalar oneyear = 52.1429


** Generate a variable including only a flatrate fee in monthly measure
gen flatrate_exp_wkly = .

replace flatrate_exp_wkly = 0 if flatrate_period == 0 // We don't pay for water
replace flatrate_exp_wkly = flatrate_fee if flatrate_period == 1 // Once every week
replace flatrate_exp_wkly = flatrate_fee/twoweeks if flatrate_period == 2 // Once every two weeks
replace flatrate_exp_wkly = flatrate_fee/onemonth if flatrate_period == 3 // Once every month
replace flatrate_exp_wkly = flatrate_fee/twomonths if flatrate_period == 4 // Once every two months
replace flatrate_exp_wkly = flatrate_fee/threemonths if flatrate_period == 7 // Once every three months
replace flatrate_exp_wkly = flatrate_fee/sixmonths if flatrate_period == 5 // Once every 6 months
replace flatrate_exp_wkly = flatrate_fee/oneyear if flatrate_period == 6 // Once every 6 months

tab flatrate_exp_wkly, mi

** Combine flatrate and per use fee into a single monthly measure
gen water_exp_wkly = .

replace water_exp_wkly = 0 if flatrate_period == 0 // We don't pay for water
replace water_exp_wkly = flatrate_fee if flatrate_period == 1 // Once every week
replace water_exp_wkly = flatrate_fee/twoweeks if flatrate_period == 2 // Once every two weeks
replace water_exp_wkly = flatrate_fee/onemonth if flatrate_period == 3 // Once every month
replace water_exp_wkly = flatrate_fee/twomonths if flatrate_period == 4 // Once every two months
replace water_exp_wkly = flatrate_fee/threemonths if flatrate_period == 7 // Once every three months
replace water_exp_wkly = flatrate_fee/sixmonths if flatrate_period == 5 // Once every 6 months
replace water_exp_wkly = flatrate_fee/oneyear if flatrate_period == 6 // Once every 6 months

tab water_exp_wkly

replace water_exp_wkly = water_peruse_pay_lastwk if water_exp_wkly == .

bysort water_pay_type: tab water_exp_wkly
tab water_exp_wkly


**** Water use expenses winsorization *****
* ssc install winsor2
 *Winsorize outcomes with outliers at 99th percentile (right-winsorization only)
winsor2 water_exp_wkly, ///
 cuts(0 99) suffix(_win99) label

******** save HH-level dataset updated with these vars
save "${hp_hh_constructed}", replace

******** Data construction for all indexes ********
g WEIGHT=1

*HH water governance index construction
WMEANEFFECTS treatment_status WEIGHT comm_select_fairly fairtreat_bycomm comm_money_manage comm_response_breakd trust_comm_response satisfac_water_access if treatment_status != ., g(HH_water_gov_perception) // an if statement is required by the syntax, so include an innocuous one

****** LIFE SATISFACTION AND SELF-ESTEEM

** Reverse coding correction
recode rosenberg_3rd rosenberg_5th rosenberg_8th rosenberg_9th rosenberg_10th (0 = 3 "Strongly disagree") (1 = 2 "Disagree") (2 = 1 "Agree") (3 = 0 "Strongly agree"), gen(rosenberg_3rd_reverse rosenberg_5th_reserve rosenberg_8th_reverse rosenberg_9th_reverse rosenberg_10th_reverse) label(rosenberg_reverse)

** Index construction
WMEANEFFECTS treatment_status WEIGHT wvs rosenberg_1st rosenberg_2nd rosenberg_3rd_reverse rosenberg_4th rosenberg_5th_reserve rosenberg_6th rosenberg_7th rosenberg_8th_reverse rosenberg_9th_reverse rosenberg_10th_reverse if treatment_status != ., g(self_esteem_index) // an if statement is required by the syntax, so include an innocuous one

****** PSYCHOLOGICAL WELL-BEING

** Reverse coding correction
recode cohen_1st cohen_4th (1 = 5 "Never") (2 = 4 "Almost never") (3 = 3 "Sometimes") (4 = 2 "Fairly often") (5 = 1 "Very often"), gen(cohen_1st_reverse cohen_4th_reverse) label(cohen_reverse)

** Index construction
WMEANEFFECTS treatment_status WEIGHT who_1st who_2nd who_3rd who_4th who_5th cohen_1st_reverse cohen_2nd cohen_3rd cohen_4th_reverse if treatment_status != ., g(psych_well_being) // an if statement is required by the syntax, so include an innocuous one

****** Self-reported health behaviour and knowledge
/* Breakdown
Final definition aften discussion with the team (Jun 29):

- Knowledge
•	Caregiver knows how and when to wash hands -> create indicator = 1 if respondent mentioned unprompted that they wash hands with soap in critical juncture X (= 0 if they say no or they say it prompted), add them up to create score --> hw_score
- Sanitation practices
•	Open defecation -> =1 if no defecation facility used --> open_defecation
•	Improved latrine -> =1 if defecation facility is improved per JMP definition --> improvedsanitation
•	Frequency of latrine cleaning/maintenance --> latrine_clean_2wks
•	Improvements to latrine in past 4 years -> joint indicator equal to 1 if either HH-made or VEA-made improvements --> latrine_hh_vea_improved
•	Disposes of child feces safely (JMP definition) --> found to be missing due to programming error, need to let team know
- Water storage practices
•	Has a clean pot for water that is covered -> indicator equal to 1 if both of these things are true at the same time, i.e. pot is clean, pot is covered --> clean_covered_pot
•	Treats water (any method for now, to be narrowed down to boiling/chlorination later on most likely) before consumption --> water_treated
*/

/*
WMEANEFFECTS treatment_status WEIGHT hw_score open_defecation improvedsanitation latrine_clean_2wks latrine_hh_vea_improved clean_covered_pot water_treated if treatment_status != ., g(hygiene_behaviour_index) // an if statement is required by the syntax, so include an innocuous one
*/

WMEANEFFECTS treatment_status WEIGHT hw_score open_defecation used_soap_ash latrine_clean_2wks clean_covered_pot water_treated if treatment_status != ., g(hygiene_behaviour_index_new) // an if statement is required by the syntax, so include an innocuous one


******** save HH-level dataset updated with these vars
save "${hp_hh_constructed}", replace

******** Data construction for structured observations section *********

use "${hp_hh_constructed}", clear


*Percentage of observed events where adult hands were washed adequately (both hands washed, with soap or ash) prior to event. [Events are defined as using toilet, preparing food, eating food, or changing infant diaper/cleaning child post-toilet]

/*	   Conditions: 
					(1.1) so_any_event == 1
					(1.2) so_who_event_* == 1 | 2 // There is another option (5) capturing cases where all members of the household were observed for that event. They represent 44 event observations. We assume that for an interview at least an adult should be in the household.
	
		  Moments: so_event_*
					(2.1) after using toilet == 8 // The description of the indicator mentions prior to event but toilet is including. handwashing is normally after defecation. 
					(2.2) before preparing food == 2
					(2.3) before eating food == 4
					(2.4) after changing infant diaper/cleaning child post-toilet == 10

Secondary moments:	so_event_*
					(3.1) Before obtaining water from a wide-mouthed storage container == 1
					(3.2) Before serving food == 3
					(3.3) After eating == 5
					(3.4) Before feeding child under 5 == 6
					(3.5) Before breastfeeding child == 7
					(3.6) After toileting == 9
					(3.7) Bathing == 11
					
 Handwashing vars:  
					(4.1) so_wash_hands_*
					(4.2) so_wash_2hands_*
					(4.3) so_hw_material_*					
*/	

** How many observed events?
** How many observed events among the selected 4 events?
** How many observed events where adults were observed?
** How many (i)   observed events among the selected 4 events where 
**			(ii)  adults were observed, 
**			(iii) hands washed / 2 hands wahed
**          (iv)  soap/ash used

** Drop observation with consent=0 for structured observations
drop if so_consent == 0

tab so_any_event, mi
tab  so_any_event if so_any_event == 1 & so_event_1 != ., mi
count if so_any_event == 1 & so_event_1 == .
*br if so_any_event == 1 & so_event_1 == .


tab1 so_who_event_*, mi nol

forvalues i=1/32 {
tab so_event_`i', mi
* if so_event_`i' == 11
}
** Events involving all household members (children or adults)
gen so_event_all_count = 0

** Events involving only adults
gen so_event_adlt_count = 0 // without bathing since it does not involve literal handwashing
gen so_hw_count = 0
gen so_hw_soap_ash_count = 0
gen so_hw_soap_count = 0
gen so_hw_nosoap_ash_count = 0


forvalues i=1/32{
	** Number of events where children or adults were observed for all key critical junctures 
	replace so_event_all_count = so_event_all_count + (so_any_event == 1 & (so_event_`i' !=.))
tab so_event_all_count if so_event_all_count != 0, mi
bysort treatment_status: tab so_event_all_count if so_event_all_count != 0, mi

	** Number of events where adults were observed for all key critical junctures except bathing and handwashing after eating (washing hands "after eating" I'm not sure would be a "critical juncture" since it's not linked to a specific unhygienic activity -- assuming food isn't contaminated with feces!)
	replace so_event_adlt_count = so_event_adlt_count + (so_any_event == 1 & (inlist(so_who_event_`i', 1, 2, 5)) & (inlist(so_event_`i', 1, 2, 3, 4, 6, 7, 8, 9, 10)))
tab so_event_adlt_count if so_event_adlt_count != 0, mi 
bysort treatment_status: tab so_event_adlt_count if so_event_adlt_count != 0, mi 

	** Number of events where adults were observed wahsing hands (bathing handwashing after eating are excluded)
replace so_hw_count = so_hw_count + (so_any_event == 1 & (inlist(so_who_event_`i', 1, 2, 5)) & (inlist(so_event_`i', 1, 2, 3, 4, 6, 7, 8, 9, 10)) & so_wash_hands_`i' == 1)
tab so_hw_count, mi

	** Number of events where adults were observed wahsing hands with soap/ash (bathing handwashing after eating are excluded)
replace so_hw_soap_ash_count = so_hw_soap_ash_count + (so_any_event == 1 & (inlist(so_who_event_`i', 1, 2, 5)) & (inlist(so_event_`i', 1, 2, 3, 4, 6, 7, 8, 9, 10)) &  so_wash_hands_`i' == 1 & inlist(so_hw_material_`i', 1, 2, 3, 4, 5))
tab so_hw_soap_ash_count, mi

	** Number of events where adults were observed wahsing hands with soap only and no ash (bathing handwashing after eating are excluded)
replace so_hw_soap_count = so_hw_soap_count + (so_any_event == 1 & (inlist(so_who_event_`i', 1, 2, 5)) & (inlist(so_event_`i', 1, 2, 3, 4, 6, 7, 8, 9, 10)) &  so_wash_hands_`i' == 1 & inlist(so_hw_material_`i', 1, 2, 3, 4))
tab so_hw_soap_count, mi


	** Number of events where adults were observed wahsing hands without soap/ash [other or only water are the options available for handwashing without soap/ash] (bathing handwashing after eating are excluded)
replace so_hw_nosoap_ash_count = so_hw_nosoap_ash_count + (so_any_event == 1 & (inlist(so_who_event_`i', 1, 2, 5)) & (inlist(so_event_`i', 1, 2, 3, 4, 6, 7, 8, 9, 10)) &  so_wash_hands_`i' == 1 & inlist(so_hw_material_`i', 0, -555))
tab so_hw_nosoap_ash_count, mi

}
gen so_hw_nohw_count = so_event_adlt_count - so_hw_count


tab so_event_all_count, mi
tab so_event_adlt_count, mi
tab so_hw_count, mi
tab so_hw_soap_ash_count, mi
tab so_hw_soap_count
tab so_hw_nosoap_ash_count, mi



*br so_4events_count so_hw_soap_count so_hw_soap_count so_hw_water_count
*br so_event_adlt_count so_hw_count so_hw_soap_ash_count so_hw_soap_count so_hw_nosoap_ash_count

gen so_hw_share = so_hw_count/so_event_adlt_count
gen so_hw_soap_ash_share = so_hw_soap_ash_count/so_event_adlt_count
gen so_hw_soap_share = so_hw_soap_count/so_event_adlt_count
gen so_hw_nosoap_ash_share = so_hw_nosoap_ash_count/so_event_adlt_count

gen so_hw_hh = (so_hw_count > 0) if so_hw_count != .
gen so_hw_hh_soap_ash = (so_hw_soap_ash_count > 0) if so_hw_soap_ash_count != .
gen so_hw_hh_soap = (so_hw_soap_count > 0) if so_hw_soap_count != .
gen so_hw_hh_nosoap_ash = (so_hw_nosoap_ash_count > 0) if so_hw_nosoap_ash_count != .

tab so_hw_share, mi
tab so_hw_soap_share, mi
tab so_hw_soap_ash_share, mi
tab so_hw_nosoap_ash_share, mi

tab so_hw_hh, mi
tab so_hw_hh_soap_ash, mi
tab so_hw_hh_soap, mi
tab so_hw_hh_nosoap_ash, mi



** Labeling variables
label var so_event_all_count "Total number of events observed"
label var so_event_adlt_count "Number of events observed involving adults"
label var so_hw_count "Number of events involving adults with handwashing obverved"
label var so_hw_soap_ash_count "Number of events involving adults with soap/ash handwashing obverved"
label var so_hw_soap_count "Number of events involving adults with soap handwashing obverved"
label var so_hw_nosoap_ash_count "Number of events involving adults with no soap/ash handwashing obverved"

label var so_hw_share "Share of events involving adults with handwashing obverved"
label var so_hw_soap_ash_share "Share of events involving adults with soap/ash handwashing obverved"
label var so_hw_soap_share "Share of events involving adults with soap handwashing obverved"
label var so_hw_nosoap_ash_share "Share of events involving adults with no soap/ash handwashing obverved"

label var so_hw_hh "1 if HH has event(s) involving adults handwashing and 0 otherwise"
label var so_hw_hh_soap_ash "1 if HH has event(s) involving adults handwashing with soap/ash and 0 otherwise"
label var so_hw_hh_soap "1 if HH has event(s) involving adults handwashing with soap and 0 otherwise"
label var so_hw_hh_nosoap_ash "1 if HH has event(s) involving adults handwashing without soap/ash and 0 otherwise"

label define so_hw_hh 0 "HH with no handwashing" 1 "HH with Handwashing"
label values so_hw_hh so_hw_hh 

label define so_hw_hh_soap_ash 0 "HH Handwashing without soap/ash" 1 "HH Handwashing with soap/ash"
label values so_hw_hh_soap_ash so_hw_hh_soap_ash 

label define so_hw_hh_soap 0 "HH Handwashing without soap" 1 "HH Handwashing with soap"
label values so_hw_hh_soap so_hw_hh_soap 

** Drop HH where no event were observed **
drop if so_event_all_count == 0

******** save HH-level dataset updated with these vars
save "${hp_so_hh_level}", replace


******** Child-level construction section
use "${hp_hh_constructed}", clear

// keep only vars relevant for child level work for now (HH ID + child roster info)
*local child_vars province-survey_hh_id week winter_holiday resp_age pull_n-och_bloodstool_l2wks_23 other_child_last3yrs-nch_bloodstool_l2wks_6 starttime end_endl_child_roster enddate_child_roster // we also have dead children mini roster but not relevant for diarrhea analysis for now

* 
local child_vars midl_children_roster_count endl_children_roster_count pl_childold_gender_* treatment_status group cluster_strata province village survey_hh_id och_correct_sex_* nch_child_sex_* nch_children_yn och_age_years_calc2_* nch_age_years_calc2_* och_diarrhea_* nch_diarrhea_* och_bowel_* nch_bowel_* och_blood_stool_* nch_blood_stool_* och_watersoft_stool_* nch_watersoft_stool_* och_diarrh_l2wks_* nch_diarrh_l2wks_* och_bloodstool_l2wks_* nch_bloodstool_l2wks_* och_attendsch_lwks_* nch_attendsch_lwks_* och_schooling_* nch_schooling_* week winter_holiday

keep `child_vars'

// reshape data to long at child level
/*
* procedure to get all the "stubs" quickly for reshape given that we have a ton of variables and usual tricks (e.g. like using the hyphen in the local above) don't work with the reshape command (see more details here: https://www.stata.com/support/faqs/data-management/problems-with-reshape/)
unab vars : *_1

local stubs : subinstr local vars "1" "", all // doesn't work because we also have vars of the type *_1_@ (where the first 1 is due to a select multiple automatically created var, not a suffix like @) and this drops those "1s" as well, leaving the vars looking like och_missedsch__ (where the correct 1 is dropped and we end up with an unrecognised double underscore instead) -- need to figure out a clever way to deal with it or just drop this process and list all vars manually for the command
*/


local stubs pl_childold_gender_ och_correct_sex_ nch_child_sex_  och_age_years_calc2_ nch_age_years_calc2_ och_diarrhea_ nch_diarrhea_ och_bowel_ nch_bowel_ och_blood_stool_ nch_blood_stool_ och_watersoft_stool_ nch_watersoft_stool_ och_diarrh_l2wks_ nch_diarrh_l2wks_ och_bloodstool_l2wks_ nch_bloodstool_l2wks_ och_attendsch_lwks_ nch_attendsch_lwks_ och_schooling_ nch_schooling_ 

* reshape long
reshape long `stubs', i(survey_hh_id) j(child_id)

* drop empty rows that come out from reshaping process due to repeated rosters
drop if child_id > midl_children_roster_count // rows are artificially created by the reshape given that we have up to 23 children included in roster for some HHs, but vast majority have fewer then that, so all rows with a child id higher than the count of total preloaded children will be artificial

drop if child_id > endl_children_roster_count // this takes care of dropping remaining empty rows following first drop above (if child id higher than roster count of newly registered children, then those rows are artificially created by the reshape) 

* we still have empty rows with people who declared no children at midline and also no new children at endline, or newly recruited HHs that declared no children, so need to drop rows in which both midline and endline children count are empty, since this means no children were recorded whatsoever
drop if midl_children_roster_count == . & endl_children_roster_count == .

// unify vars from och_* (midline children roster) to nch_ (endline children roster) to have 1 single long variable containing both, e.g. date_birth as opposed to och_date_birth and nch_date_birth -- this helps because we then have all diarrhea data in single variables across "types" of children for use in graphs and analysis, so do it only for diarrhea vars for now
* diarrhea vars: och_diarrhea_ och_bowel_ och_watersoft_stool_ och_blood_stool_ och_diarrh_weekday_ och_diarrh_length_w_ och_diarrh_length_d_ och_diarrh_l2wks_ och_bloodstool_l2wks_ nch_diarrhea_ nch_bowel_ nch_watersoft_stool_ nch_blood_stool_ nch_diarrh_weekday_ nch_diarrh_length_w_ nch_diarrh_length_d_ nch_diarrh_l2wks_ nch_bloodstool_l2wks_
* PROBLEM: we have midline children and new children side by side, so we can't do an "append" of all diarrhea values sequentially, i.e. as if we had all old children + all new children lined up sequentially. Need to think of way to do it. One way might be to use the och_ and nch_ stub with the "string" option while doing another reshape, so that it creates a new var named something like roster_type which includes strings of "och_" or "nch_", and data are once again reshaped long. That will then allow us to have a "merged" total diarrhea var with sequential values for old+new children, and a dataset that's truly at the child level

* create uniquely identifying "i" for new reshape, i.e. concatenated survey_hh_id + child_id
egen hh_child_id = concat(survey_hh_id child_id)

// Construct child age and sex related variables
tab pl_childold_gender_, mi
tab och_correct_sex_, mi nol

gen och_child_sex_ = 1 if pl_childold_gender_ == "Female"
replace och_child_sex_ = 2 if pl_childold_gender_ == "Male"
replace och_child_sex_ = och_correct_sex_ if och_correct_sex_ != och_child_sex_ & och_correct_sex_!=.


drop pl_childold_gender_ // creates confusion with stub below so try dropping them to see if it works, they're preload vars inside the roster anyway so not relevant

reshape long @_member_ @_miss_why_ @_miss_why_1_ @_miss_why_2_ @_miss_why__555_ @_miss_why_oth_ @_mistake_field_ @_mistake_field_1_ @_mistake_field_2_ @_child_sex_ @_correct_sex_ @_day_of_birth_ @_month_of_birth_ @_year_of_birth_ @_day_ @_month_ @_year_ @_day_of_birth_n_ @_month_of_birth_n_ @_days_adjust_ @_adjusted_month_ @_month_adjust_ @_age_years_calc_ @_age_months_calc_ @_birth_source_ @_birthoth_official_doc_ @_birth_source_oth_ @_age_years_ @_age_years_calc2_ @_schooling_ @_attendsch_lwks_ @_missedsch_why_ @_missedsch_why_1_ @_missedsch_why_2_ @_missedsch_why_3_ @_missedsch_why_4_ @_missedsch_why_5_ @_missedsch_why_6_ @_missedsch_why_7_ @_missedsch_why__555_ @_missedsch_why_oth_ @_fever_ @_diarrhea_ @_bowel_ @_watersoft_stool_ @_blood_stool_ @_skinrash_ @_constcough_ @_runnose_ @_panting_ @_bruising_ @_teething_ache_ @_diarrh_weekday_ @_diarrh_length_w_ @_diarrh_length_d_ @_diarrh_l2wks_ @_bloodstool_l2wks_, i(hh_child_id) j(roster_type) string

* create new unique id concatenating hh_child_id with the new roster type var
egen hh_child_roster_id = concat(hh_child_id roster_type)

// there should be artificially created rows whenever we have midline HHs who declared no new children (all rows tagged "nch" under roster_type would be meaningless for them) or only new HHs who by design can't have any meaningful info in rows tagged "och" under roster_type or midline HHs who only declared new children while having previously not declared any at midline
drop if nch_children_yn == 0 & roster_type == "nch" // this means: drop all rows tagged "nch" (new children) when the answer to the question "any new children" is equal to "0 = No", since these rows will contain no information

drop if midl_children_roster_count == . & roster_type == "och" // drop all rows tagged "och" whenever there were actually no midline children recorded

/* according to this we have 5250 children combining both old and new, consider that we have about 2500 anthro tests done and 3407 HHs and that these are children under 6 (not total children), it's about an average of little less than 2 kids under 6 per HH, which sounds reasonable
*/

// Re treatment status: we may decide to use vea_status, which is the treatment status updated at endline based on the thorough verification done by the field team (e.g. check all VEA materials, talk to senior leadership, etc) and taking into account discrepancies (e.g. ask the enumerator to confirm and verify based on discrepancy, etc). We may also combine it with assigned treatment_status from the village list prepared prior to midline. For now we can use vea_status as treatment var for the analyses.

// recode child sex
recode _child_sex_ (1 = 1 Female) (2 = 0 Male), gen(child_sex) label(sex)

gen child_age_years = _age_years_calc2_

// use commands from anthro dofile to create date of birth vars from day, month, year separate vars (if needed, not sure yet--we have age in years already)

// create diarrhea indicator based on PAP decision
generate 	diarrhea_outcome = 0
replace 	diarrhea_outcome = 1 if _diarrhea_ == 1 | (_watersoft_stool_ == 1 & _bowel_ == 1) | _blood_stool_ == 1
replace		diarrhea_outcome = . if missing(_diarrhea_, _watersoft_stool_, _bowel_, _blood_stool_) // more precise to have this missing if all the variables that "constitute" it are also missing, as opposed to 0, this has implications for proportions (e.g. if we do a descriptive graph, missing values are ignored compared to 0 values of course)
label var diarrhea_outcome "Diarrhea"

/* Diarrhea sensitivity analysis: We will use two-week recall as a sensitivity analysis. In this approach, we will code a child as positive for diarrhea if the respondent answers
1. Yes to `diarrhea', or
2. Yes to `blood in the stool'
*/
generate 	diarrhea_outcome_2wks = 0
replace 	diarrhea_outcome_2wks = 1 if _diarrh_l2wks_ == 1 | _bloodstool_l2wks_ == 1
replace		diarrhea_outcome_2wks = . if missing(_diarrh_l2wks_) // _bloodstool_l2wks_ is asked as a follow-up to _diarrh_l2wks_, so can't use command above (otherwise we would either have 1 or missing values, no 0 values), so only set it to missing when _diarrh_l2wks_ is missing, and then mechanically _bloodstool_l2wks_ will be missing too in those cases, but at leaste we capture as 0 values all the instances of _diarrh_l2wks_ == 0, which we would otherwise miss


***** School attendance for 6-18 children
tab _attendsch_lwks_ _schooling_, mi
gen attendsch_lwks_unc = _attendsch_lwks_
replace attendsch_lwks_unc = 0 if _schooling_ == 0
tab1 _attendsch_lwks_ attendsch_lwks_unc, mi

gen child_6to18_attendsch_lwks = attendsch_lwks_unc if child_age_years >= 6 & child_age_years <= 18
tab child_6to18_attendsch_lwks // 525 obs
tab child_age_years, mi
count if child_age_years >= 6 & child_age_years <= 18 // 526 obs

label var child_6to18_attendsch_lwks "Days children aged 6-18 attended school in past week"

gen child_6to18_attendsch_lwk2 = _attendsch_lwks_ if child_age_years >= 6 & child_age_years <= 18
label var child_6to18_attendsch_lwk2 "Days children aged 6-18 attended school in past week"


tab _schooling_, mi
gen child_schooling_6to18 = (_schooling_ == 1) if child_age_years >= 6 & child_age_years <= 18 & _schooling_ != .
tab child_schooling_6to18, mi

gen schooling_attendsch_lwks = _attendsch_lwks_ if _schooling_ == 1
tab schooling_attendsch_lwks, mi
tab schooling_attendsch_lwks

label var schooling_attendsch_lwks "Days schooling children attended school in past week"

**** Add treatment status & cluster info to dataset so that it can be used for analysis
merge m:1 village using "${hp_village_list}", keepusing(treatment_status group cluster_strata) // 3 villages not matched from master list, consistent with villages having been dropped

drop if _merge == 2

drop _merge

***** save child roster level data for now
save "${hp_hh_child_roster}", replace // unique ID var is hh_child_roster_id, no duplicates


* end of dofile *
