/*******************************************************************************
*             Healthy Villages and Schools National Program (VEA),             *
*			  Democratic Republic of Congo                                     *
*             MASTER DO_FILE                                                   *
********************************************************************************
*                                                                              *
*   PURPOSE:     Reproduce all data work, map inputs and outputs of the 
*				 VEA health paper                                              *
*                                                                              *
*                                                                              *
*   OUTLINE:     PART 1:  Set standard settings and install packages           *
*                PART 2:  Prepare folder paths and define programs             *
*                PART 3:  Run do-files                                         *
*                                                                              *
*	LAST UPDATE: Nov 16, 2024                                                  *
*                                                                              *
********************************************************************************



    PART 1:  Install user-written packages and harmonize settings
********************************************************************************/

	global ProjectFolder 	"" 
	sysdir set PLUS "${ProjectFolder}/Dofiles/ado"

	/*
    local user_commands ietoolkit winsor2 estout etime //Add required user-written commands
    foreach command of local user_commands {
        cap which `command'
        if _rc == 111 ssc install `command'
    }
	*/

    *Harmonize settings across users as much as possible
    ieboilstart, v(16.0)
    `r(version)'

* Start the timer at the beginning of the do-file and display elapsed time at the end of the do-file
etime, start

/*******************************************************************************
    PART 2:  Prepare folder paths and define programs
*******************************************************************************/

**==============================================================================	 


**==============================================================================


**** Folder paths for Data and Code necessary for running the reproducibility package	
**==============================================================================

**** Health Paper Folders - Code

	global hp_dofiles		  "${ProjectFolder}/Dofiles"
	global hp_vl_do           "${hp_dofiles}/Village_leadership"
	global hp_hh_do 		  "${hp_dofiles}/Household"
	global hp_anthro_do		  "${hp_dofiles}/Anthropometric"
	global hp_wp_do			  "${hp_dofiles}/Water_point_mapping"
	global hp_hhw_do 		  "${hp_dofiles}/Household_water_testing"
	
	global hp_mastdata_do 	  "${hp_dofiles}/Master_Data"
	
	global hp_tables_do 	  "${hp_dofiles}/Tables"
	global hp_graphs_do 	  "${hp_dofiles}/Graphs"
	
	global hp_programs_do     "${hp_mastdata_do}/Programs"
	
	
**** Health Paper Folders - Data	

** Data folders
	global hp_data_db         "${ProjectFolder}/Data"
	global hp_data_db_raw     "${hp_data_db}/Raw"
	global hp_data_db_int     "${hp_data_db}/Intermediate"
	global hp_data_db_final   "${hp_data_db}/Final"
	global hp_data_db_master  "${hp_data_db}/Master_Data"

** Analysis folders
	global hp_analysis 		  "${ProjectFolder}/Analysis"
	global hp_tables 		  "${hp_analysis}/Tables"
	global hp_graphs 		  "${hp_analysis}/Graphs"

** Ado file folder
	global hp_igrowup_ado 	  "${ProjectFolder}/Documentation/02_igrowup" 
	
	

** Master Data
	global hp_village_list	  "${hp_data_db_master}/village_list_health_paper.dta"
	
	global rando_fulldata "${hp_data_db_master}/rando_fulldata.dta"

** Household survey data 
	global hp_hh_raw_deid		  "${hp_data_db_raw}/Household_Endline_raw_health_paper.dta" 
	
	global hp_hh_clean		   "${hp_data_db_int}/Household_Endline_clean_health_paper.dta"
	
	global hp_hh_constructed       "${hp_data_db_final}/Household_Endline_constructed_health_paper.dta"
	
	global hp_so_hh_level          "${hp_data_db_final}/Structured_obs_Endline_hh_level_health_paper.dta"

	global hp_hh_child_roster      "${hp_data_db_final}/Chlid_roster_Endline_health_paper.dta"
	
	
** Village leadership survey data
	global hp_vl_raw_deid          "${hp_data_db_raw}/Leaders_Endline_raw_health_paper.dta" 
	global hp_vl_clean		       "${hp_data_db_int}/Leaders_Endline_clean_health_paper.dta"
	
	global hp_vl_constructed       "${hp_data_db_final}/Leaders_Endline_constructed_health_paper.dta"
	
	global hp_anthro_raw_deid      "${hp_data_db_raw}/Anthro_Endline_raw_health_paper.dta"
	
	global hp_anthro_clean         "${hp_data_db_int}/Anthro_Endline_clean_health_paper.dta"
	
	global hp_anthro_z_constructed "${hp_data_db_final}/Anthro_z_st_constructed_health_paper.dta"
	
	
** Water point mapping survey data
	global hp_wp_raw_deid          "${hp_data_db_raw}/WP_Mapping_Endline_raw_health_paper.dta"
	
	global hp_wp_clean             "${hp_data_db_int}/WP_Mapping_Endline_clean_health_paper.dta"
	
	global hp_wp_constructed       "${hp_data_db_final}/WP_Mapping_Endline_constructed_health_paper.dta"
	

** Houshold water testing survey data
	global hp_hhw_raw_deid         "${hp_data_db_raw}/HH_Water_Test_Endline_raw_health_paper.dta"
	global hp_hhw_clean            "${hp_data_db_int}/HH_Water_Test_Endline_clean_health_paper.dta"
	
	global hp_hhw_constructed      "${hp_data_db_final}/HH_Water_Test_Endline_constructed_health_paper.dta"

**=============================================================================


/*******************************************************************************
    PART 3: Run do-files
*******************************************************************************/

 * Household survey data (cleaning and construction)
**------------------------------------------------------------------------------
* The number next to "if" should be 1 for this part to run and 0 for the code not to run
if (1) { 

do "${hp_hh_do}/02_hh_cleaning_health_paper.do" // Produce clean data
do "${hp_programs_do}/index_construction_program.do" // Program creating index variables
do "${hp_hh_do}/03_hh_construct_health_paper.do" // Produce analysis data

}
*-------------------------------------------------------------------------------

 * Village leadership survey data (cleaning and construction)
**------------------------------------------------------------------------------
* The number next to "if" should be 1 for this part to run and 0 for the code not to run
if (1) {
 
do "${hp_vl_do}/02_vl_cleaning_health_paper.do" // Produce clean data
do "${hp_vl_do}/03_vl_construct_health_paper.do" // Produce analysis data

}
*-------------------------------------------------------------------------------


 * Anthropometric survey data (cleaning and construction)
**------------------------------------------------------------------------------
* The number next to "if" should be 1 for this part to run and 0 for the code not to run
if (1) {

do "${hp_anthro_do}/04_anthro_cleaning_health_paper.do" // Produce clean data
do "${hp_anthro_do}/05_anthro_construct_health_paper.do" // Produce analysis data

}
*-------------------------------------------------------------------------------

 * Water point mapping survey data (cleaning and construction)
**------------------------------------------------------------------------------
* The number next to "if" should be 1 for this part to run and 0 for the code not to run
if (1) {

do "${hp_wp_do}/04_wp_cleaning_health_paper.do" // Produce clean data
do "${hp_programs_do}/index_construction_program.do" // Program creating index variable
do "${hp_wp_do}/05_wp_construct_health_paper.do" // Produce analysis data

}
*--------------------------------------------------------------------------------

 * Household water testing survey data (cleaning and construction)
**------------------------------------------------------------------------------
* The number next to "if" should be 1 for this part to run and 0 for the code not to run
if (1) {

do "${hp_hhw_do}/04_hhw_cleaning_health_paper.do" // Produce clean data
do "${hp_hhw_do}/05_hhw_construct_health_paper.do" // Produce analysis data

}
*-------------------------------------------------------------------------------


 * Data Analysis: Tables
**------------------------------------------------------------------------------
* The number next to "if" should be 1 for this part to run and 0 for the code not to run
if (1) {

** Main tables
do "${hp_tables_do}/table_2_health_paper.do"
do "${hp_tables_do}/table_3_health_paper.do"
do "${hp_tables_do}/table_4_health_paper.do"

** Tables for supplementary materials
do "${hp_tables_do}/table_s1_health_paper.do"
do "${hp_tables_do}/table_s2_health_paper.do"
do "${hp_tables_do}/table_s3_health_paper.do"
do "${hp_tables_do}/table_s4_health_paper.do"
do "${hp_tables_do}/table_s5_health_paper.do"
do "${hp_tables_do}/table_s6_health_paper.do"
do "${hp_tables_do}/table_s7_health_paper.do"

}
*-------------------------------------------------------------------------------

* Stop the timer at the end of the do-file and display elapsed time
etime



exit
